<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  セットアップ情報登録用のActionクラス
 *
 *  @author     Shogo Minami
 *  @access     public
 *  @package    PocketBBS.setup.do
 */
class setupAction extends Pocket_Bbs_Action
{
    /**
     *  アクション実行
     *
     *  @access public
     *  @param  object  $controller         コントローラ
     *  @param  object  $request            リクエスト情報
     *  @return string  success,error
     */
    function execute(&$controller, &$request)
    {
        // リクエスト情報の取得
        $mysql_type = $request['mysql_type'];
        $id         = $request['id'];
        $email      = $request['email'];
        $password   = $request['password'];
        $bbs_name   = $request['BBS_NAME'];

        // セットアップファイルパスの取得、設定
        $files = $this->assignSetUpFiles($mysql_type);

        // 一時 create_tables ファイルの読込
        $lines = @file($files['create_tables']);

        foreach ($lines as $item)
        {
            // 文字連結
            $sql .= $item;

            if (mb_strpos($item, ";"))
            {
                // テーブルの作成
                if (DB::isError(pocket_db_query($sql)))
                    pocket_redirect('setupError.view');

                // 変数の割当解除
                unset($sql);
            }
        }

        // BBS設定の登録
        db_insert_bbs_config('BBS_NAME', $bbs_name);
        db_insert_bbs_config('BBS_INTRO', '');
        db_insert_bbs_config('NEWS_SIZE', 5);
        db_insert_bbs_config('PAGE_SIZE', 5);
        db_insert_bbs_config('IS_TOPIC_ENTRY', intval(true));
        db_insert_bbs_config('IS_TOPIC_MAIL', intval(false));
        db_insert_bbs_config('IS_COMMENT_MAIL', intval(false));

        // ユーザ情報の登録
        $user_id = db_insert_userEasyProfile($id);

        // メールアドレスの更新
        db_update_userEmail($user_id, pocket_encrypt($email, POCKET_BBS_ENCRYPT_KEY));

        // パスワードの更新
        db_update_userPassword($user_id, md5($password));

        // カテゴリの登録
        db_insert_category('その他', 'その他', 0, 100);

        // リダイレクト
        pocket_redirect('setupComplete.view', array('email' => $email));
    }

    /**
     *  リクエスト検証
     *
     *  @access public
     *  @param  object  $validator          バリデータ
     *  @param  object  $request            リクエスト情報
     */
    function validate(&$validator, &$request)
    {
        // リクエスト情報の取得
        $mysql_type = $request['mysql_type'];
        $id         = $request['id'];
        $email      = $request['email'];
        $password   = $request['password'];
        $bbs_name   = $request['BBS_NAME'];

        // エラー表示用のAction名称の設定
        $this->viewAction = 'default';

        // 検証
        $validator->validate('mysql_type', 'MySQL種別'     , $mysql_type, 'string', true);
        $validator->validate('id'        , 'ユーザID'      , $id        , 'string', true);
        $validator->validate('email'     , 'メールアドレス', $email     , 'email' , true);
        $validator->validate('password'  , 'パスワード'    , $password  , 'alnum' , true);
        $validator->validate('bbs_name'  , 'BBS名称'       , $bbs_name  , 'string', true);

        // パスワードの桁数チェック
        if (strlen($password) < 6 || strlen($password) > 12)
        {
            $validator->addErrors('password', 'パスワードの桁数が不正です。');
        }

        // ENCRYPT_KEYの設定チェック
        if (!(defined('POCKET_BBS_ENCRYPT_KEY') && POCKET_BBS_ENCRYPT_KEY) || strlen(POCKET_BBS_ENCRYPT_KEY) > 56)
        {
            $validator->addErrors('encrypt_key', '暗号化用の鍵が適切に設定されていません。config.phpの内容を確認してください。');
        }

        // DBサーバの設定チェック
        if (!$GLOBALS['_POCKET_DSN']['database'] || !$GLOBALS['_POCKET_DSN']['username'] || !$GLOBALS['_POCKET_DSN']['password'])
        {
            $validator->addErrors('database', 'データベース情報が適切に設定されていません。config.phpの内容を確認してください。');
        }

        // セットアップファイルパスの取得、設定
        $files = $this->assignSetUpFiles($mysql_type);

        // create_tablesファイルの存在チェック
        if (!file_exists($files['create_tables']))
        {
            $validator->addErrors('create_tables', 'create_tablesファイルが存在しません。');
        }
    }

    /**
     *  セットアップSQLファイルパスを配列に設定
     *
     *  @access public
     *  @param  string  $mysql_type         MySQL種別
     *  @return array
     */
    function assignSetUpFiles($mysql_type)
    {
        $files = array();

        // DB種別の判定
        if (pocket_db_isMySQL())
        {
            // MySQL種別の判定
            if ($mysql_type == '4.0')
            {
                // MySQL4.0用 create_tablesファイルの設定
                $files['create_tables'] = BASE_DIR . '../setup/sql/install/create_tables_mysql40_pocketbbs.sql';
            }
            else {
                // MySQL4.1用 create_tablesファイルの設定
                $files['create_tables'] = BASE_DIR . '../setup/sql/install/create_tables_mysql41_pocketbbs.sql';
            }
        }
        else
        {
            // PostgreSQL用 create_tablesファイルの設定
            $files['create_tables'] = BASE_DIR . '../setup/sql/install/create_tables_pgsql74_pocketbbs.sql';
        }

        return $files;
    }
}

?>
